Pachyderm Client
================

.. autoclass:: pachypy.client.PachydermClient
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:

.. autoclass:: pachypy.client.PachydermCommit
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:

Container Registry Adapters
===========================

.. automodule:: pachypy.registry
    :members:
    :undoc-members:
    :show-inheritance:
